@@ -1,5 +1,5 @@
 {- hpodder component
-Copyright (C) 2006 John Goerzen <jgoerzen@complete.org>
+Copyright (C) 2006-2007 John Goerzen <jgoerzen@complete.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -35,7 +35,9 @@ cmd_worker gi (_, [url]) =
                                             castname = "",
                                             feedurl = url,
                                             lastupdate = Nothing,
-                                            pcenabled = True})
+                                            pcenabled = PCEnabled,
+                                            lastattempt = Nothing,
+                                            failedattempts = 0})
        commit (gdbh gi)
        printf "Podcast added:\n    URL: %s\n    ID: %d\n" url (castid pc)
 
