@@ -1,5 +1,5 @@
 {- hpodder component
-Copyright (C) 2006 John Goerzen <jgoerzen@complete.org>
+Copyright (C) 2006-2007 John Goerzen <jgoerzen@complete.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -39,10 +39,10 @@ cmd = simpleCmd "rm"
       "Remove podcast(s) from hpodder" helptext 
       [] cmd_worker
 
-cmd_worker gi ([], []) =
+cmd_worker gi ([], []) = 
     fail $ "rm requires a podcast ID to remove; please see hpodder rm --help"
 
-cmd_worker gi ([], casts) =
+cmd_worker gi ([], casts) = lock $
     do podcastlist <- getSelectedPodcasts (gdbh gi) casts
        i "Will remove the following podcasts:\n"
        Commands.Ls.lscasts_worker gi ([("l", "")], casts)
