@@ -1,5 +1,5 @@
 {- hpodder component
-Copyright (C) 2006 John Goerzen <jgoerzen@complete.org>
+Copyright (C) 2006-2007 John Goerzen <jgoerzen@complete.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -47,7 +47,7 @@ cmd = simpleCmd "setup"
       "Perform initial configuration of hpodder -- NOT USER-VISIBLE" ""
       [] cmd_worker
 
-cmd_worker gi ([], []) =
+cmd_worker gi ([], []) = lock $
     do cp <- loadCP
        putStr "Hello!  Welcome to hpodder!\n\n\
  \It looks like this is your first time running hpodder, so we're going\n\
