@@ -1,5 +1,5 @@
 {- hpodder component
-Copyright (C) 2006 John Goerzen <jgoerzen@complete.org>
+Copyright (C) 2006-2007 John Goerzen <jgoerzen@complete.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 {- |
    Module     : Main
-   Copyright  : Copyright (C) 2006 John Goerzen
+   Copyright  : Copyright (C) 2006-2007 John Goerzen
    License    : GNU GPL, version 2 or above
 
    Maintainer : John Goerzen <jgoerzen@complete.org>
@@ -32,6 +32,8 @@ Written by John Goerzen, jgoerzen\@complete.org
 import Config
 import DB
 import System.Log.Logger
+import System.Log.Handler.Simple
+import System.IO(stdout)
 import System.Console.GetOpt.Utils
 import System.Console.GetOpt
 import System.Environment
@@ -56,7 +58,10 @@ options = [Option "d" ["debug"] (NoArg ("d", "")) "Enable debugging",
 
 worker args n commandargs =
     do when (lookup "help" args == Just "") $ usageerror ""
-       when (lookup "d" args == Just "") $ updateGlobalLogger "" (setLevel DEBUG)
+       when (lookup "d" args == Just "") 
+            (updateGlobalLogger "" (setLevel DEBUG))
+       handler <- streamHandler stdout DEBUG
+       updateGlobalLogger "" (setHandlers [handler])
        initDirs
        let commandname = head cmdargs
        case lookup commandname allCommands of
@@ -79,4 +84,4 @@ usageerror errormsg =
        exitFailure
 
 header = "Usage: hpodder [global-options] command [command-options]\n\n\
-         \Available global-options are:\n"
\ No newline at end of file
+         \Available global-options are:\n"
